==> openvdb-12.1.1-2-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/namespaceopenvdb_1_1v12__1_1_1tools_1_1valxform.js <==
var namespaceopenvdb_1_1v12__1_1_1tools_1_1valxform =
[
    [ "CopyableOpApplier", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1CopyableOpApplier.html", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1CopyableOpApplier" ],
    [ "CopyableOpTransformer", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1CopyableOpTransformer.html", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1CopyableOpTransformer" ],
    [ "MaxOp", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MaxOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MaxOp" ],
    [ "MinOp", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MinOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MinOp" ],
    [ "MultOp", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MultOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MultOp" ],
    [ "MultOp< bool >", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MultOp_3_01bool_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MultOp_3_01bool_01_4" ],
    [ "OpAccumulator", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1OpAccumulator.html", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1OpAccumulator" ],
    [ "SharedOpApplier", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SharedOpApplier.html", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SharedOpApplier" ],
    [ "SharedOpTransformer", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SharedOpTransformer.html", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SharedOpTransformer" ],
    [ "SumOp", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SumOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SumOp" ],
    [ "SumOp< bool >", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SumOp_3_01bool_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SumOp_3_01bool_01_4" ]
];

==> openvdb-12.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/OpenVDB/html/namespaceopenvdb_1_1v12__1_1_1tools_1_1valxform.js <==
var namespaceopenvdb_1_1v12__1_1_1tools_1_1valxform =
[
    [ "MinOp", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MinOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MinOp" ],
    [ "MaxOp", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MaxOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MaxOp" ],
    [ "SumOp", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SumOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SumOp" ],
    [ "SumOp&lt; bool &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SumOp_3_01bool_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SumOp_3_01bool_01_4" ],
    [ "MultOp", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MultOp.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MultOp" ],
    [ "MultOp&lt; bool &gt;", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MultOp_3_01bool_01_4.html", "structopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1MultOp_3_01bool_01_4" ],
    [ "SharedOpApplier", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SharedOpApplier.html", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SharedOpApplier" ],
    [ "CopyableOpApplier", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1CopyableOpApplier.html", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1CopyableOpApplier" ],
    [ "SharedOpTransformer", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SharedOpTransformer.html", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1SharedOpTransformer" ],
    [ "CopyableOpTransformer", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1CopyableOpTransformer.html", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1CopyableOpTransformer" ],
    [ "OpAccumulator", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1OpAccumulator.html", "classopenvdb_1_1v12__1_1_1tools_1_1valxform_1_1OpAccumulator" ]
];
